@@ -98,6 +98,7 @@ class HdDB:
             self.create_hd_tables()
             self.create_hd_database(org, db, len(dataframes))
             self.create_hd_fields(all_metadata)
+            self.create_hd_views(org, db)
         except duckdb.Error as e:
             raise QueryError(f"Error executing query: {e}")
 
@@ -941,3 +942,51 @@ class HdDB:
         except (duckdb.Error, Exception) as e:
             logger.error(f"Error fetching tables: {e}")
             raise QueryError(f"Error fetching tables: {e}")
+    
+    @attach_motherduck
+    def create_hd_views(self, org: str, db: str):
+        try:
+            self.execute("BEGIN TRANSACTION;")
+
+            create_query = f"CREATE TABLE \"{org}__{db}\".hd_views (id VARCHAR, user_table VARCHAR, type VARCHAR, config JSON);"
+            self.execute(create_query)
+
+            self.execute("COMMIT;")
+
+            return True
+        except duckdb.Error as e:
+            self.execute("ROLLBACK;")
+            raise QueryError(f"Error executing query: {e}")
+    
+    @attach_motherduck
+    def insert_hd_views(self, org: str, db: str, id: str, tbl: str, type: str, config: dict):
+        try:
+            insert_query = f"INSERT INTO \"{org}__{db}\".hd_views (id, user_table, type, config) VALUES (?, ?, ?, ?);"
+            self.execute(insert_query, [id, tbl, type, config])
+        except duckdb.Error as e:
+            raise QueryError(f"Error executing query: {e}")
+        
+    @attach_motherduck
+    def update_hd_views(self, org: str, db: str, id: str, config: dict):
+        try:
+            update_query = f"UPDATE \"{org}__{db}\".hd_views SET config = ? WHERE id = ?"
+            self.execute(update_query, [config, id])
+        except duckdb.Error as e:
+            raise QueryError(f"Error executing query: {e}")
+
+    @attach_motherduck
+    def delete_hd_views(self, org: str, db: str, id: str):
+        try:
+            delete_query = f"DELETE FROM \"{org}__{db}\".hd_views WHERE id = ?"
+            self.execute(delete_query, [id])
+        except duckdb.Error as e:
+            raise QueryError(f"Error executing query: {e}")
+        
+    @attach_motherduck
+    def get_hd_views(self, org: str, db: str, id: str):
+        try:
+            query = f"SELECT * FROM \"{org}__{db}\".hd_views WHERE id = ?"
+            result = self.execute(query, [id]).fetchdf()
+            return result.to_dict(orient="records")[0]["config"]
+        except duckdb.Error as e:
+            raise QueryError(f"Error executing query: {e}")
\ No newline at end of file
