@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import List, Dict, Optional
+from typing import Dict, Optional, List
 from pydantic import BaseModel
 
 
@@ -20,7 +20,7 @@ class TextFilter(BaseModel):
 
 
 class FilterModel(BaseModel):
-    filterType: str = "text"  # Por ahora solo texto
+    filterType: str = "text"
     type: TextFilterType
     filter: str
 
@@ -30,7 +30,8 @@ class FetchParams(BaseModel):
     end_row: int
     sort: Optional[str] = None
     filter_model: Optional[Dict[str, FilterModel]] = None
-    group: Optional[str] = None
+    row_group_cols: Optional[List[str]] = []
+    group_keys: Optional[List[str]] = []
 
 
 class FieldsParams(BaseModel):
